@@ -344,7 +344,7 @@ Preprocessor = Callable[[Type], Any]
 default_preprocessors: List[Tuple[Callable[[Type], bool], Preprocessor]] = [
 		(lambda d: isinstance(d, ModuleType), lambda d: Module(d.__name__)),
 		(lambda d: isinstance(d, FunctionType), lambda d: Function(d.__name__)),
-		(lambda d: inspect.isclass(d), lambda d: Class(d.__name__)),
+		(inspect.isclass, lambda d: Class(d.__name__)),
 		(lambda d: d is Ellipsis, lambda d: etc),
 		(lambda d: d == "...", lambda d: etc),
 		]
@@ -488,9 +488,14 @@ def process_signature(
 		if inspect.isclass(original_obj) or (what == "method" and name.endswith(".__init__")):
 			del parameters[0]
 		elif what == "method":
-			outer = inspect.getmodule(obj)
-			for clsname in obj.__qualname__.split('.')[:-1]:
-				outer = getattr(outer, clsname)
+
+			try:
+				outer = inspect.getmodule(obj)
+				if outer is not None:
+					for clsname in obj.__qualname__.split('.')[:-1]:
+						outer = getattr(outer, clsname)
+			except AttributeError:
+				outer = None
 
 			method_name = obj.__name__
 			if method_name.startswith("__") and not method_name.endswith("__"):
@@ -500,9 +505,14 @@ def process_signature(
 				class_name = obj.__qualname__.split('.')[-2]
 				method_name = f"_{class_name}{method_name}"
 
-			method_object = outer.__dict__[method_name] if outer else obj
-			if not isinstance(method_object, (classmethod, staticmethod)):
-				del parameters[0]
+			if outer is not None:
+				method_object = outer.__dict__[method_name] if outer else obj
+				if not isinstance(method_object, (classmethod, staticmethod)):
+					del parameters[0]
+
+			else:
+				if not inspect.ismethod(obj) and parameters[0].name in {"self", "cls", "_cls"}:
+					del parameters[0]
 
 	signature = signature.replace(parameters=parameters, return_annotation=inspect.Signature.empty)
 
